#
# spec file for package exif
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           exif
BuildRequires:  libexif-devel
BuildRequires:  pkgconfig
BuildRequires:  popt-devel
URL:            http://sourceforge.net/projects/libexif
Summary:        Small Command Line Utility to Show and Change EXIF Information in JPEG Files
License:        GPL-2.0-or-later
Group:          Productivity/Graphics/Other
Version:        0.6.22
Release:        bp155.2.10
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Source0:        %{name}-%{version}.tar.bz2
Patch0:         0001-pass-in-unsinged-int-related-to-https-github.com-lib.patch
Patch1:         0001-second-fix-for-https-github.com-libexif-exif-issues-.patch

%description
Exif is a small command line utility to show and change EXIF
information hidden in JPEG files. It demonstrate the power of libexif
library.

%prep 
%setup -q
%patch0 -p1
%patch1 -p1

%build
%configure
make %{?_smp_mflags}

%check
make check

%install
make DESTDIR=${RPM_BUILD_ROOT}/ install
%find_lang %{name}

%files -f %{name}.lang
%defattr(-,root,root)
/usr/bin/exif
%doc %{_mandir}/man1/exif.1.gz

%changelog
* Mon Jul  6 2020 Marcus Meissner <meissner@suse.com>
- fixed an endiannes issue that broke exif -i option on big endian.
  - 0001-pass-in-unsinged-int-related-to-https-github.com-lib.patch
  - 0001-second-fix-for-https-github.com-libexif-exif-issues-.patch
* Wed May 20 2020 Marcus Meissner <meissner@suse.com>
- updated to exif 0.6.22:
  * New translations: ast, fur, ko, ms, pt_BR, ru, tr
  * Updated translations: many!
  * Fix a number of compiler and automake warnings
  * Fix the --remove option when no tag is specified.
  * Escape special XML characters in xml mode.
  * Add many continuous integration builds
  * Add more regression tests
  * Fixup IFD 1 tags when adding or removing a thumbnail.
  * Fix the XML tags used in --ids format.
  * Fix a memory leak when no arguments are given.
  * Enable AM_SILENT_RULES by default.
  * Make sure the tag buffer in show_entry_xml is NUL-terminated.
  * Eliminated unnecessary remove() calls in jpeg_data_save_file.
  * Close files before logging the error.
  * Install a SIGPIPE handler to stop generating a signal on pipe failures.
  * Fix cross-compilation with pkg-config
  * Use GP_CHECK_LIBRARY to look for popt.
  * Include strings to translate from libjpeg/jpeg-data.c
  * Fixed a double free by initializing data variable to NULL
  * Check that JPEGs start with 0xff
* Mon Dec 22 2014 meissner@suse.com
- build with PIE
* Thu Jul 12 2012 meissner@suse.com
- * Prevent NULL pointer dereference on out of memory situation.
    Such a situation could be created when processing an extremely
    large JPEG file.
  * libjpeg/jpeg-data.c: Fixed bug that caused exif to read past the end
    of a buffer. At worst, data->size would underflow which would cause
    a gigantic read past the end of the heap buffer and likely
    subsequent crash, which would only happen with a corrupted
    input file. It might be possible to copy sensitive information
    from process memory.
    This fixes CVE-2012-2845
- lots of translation updates
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant/obsolete tags/sections from specfile
  (cf. packaging guidelines)
- Use %%_smp_mflags for parallel build
* Fri Dec 17 2010 meissner@suse.de
- updated to exif 0.6.20:
  * New translation: ro
  * Updated translations: it, lv, sk
  * --no-fixup now honoured during --create-exif to not create default tags
  * Fixed crash when not enough components were given to --set-value
  * Made --set-value more forgiving of whitespace
  * Allow --set-value on UNDEFINED tags (treating them as byte arrays)
  * Honour --machine-readable with --show-mnote and --show-description
  * Turned on the --enable-silent-rules configure option
  * Adding or removing a thumbnail can be done simultaneously with other options
  * Allow --create-exif to be used in place of an input file
* Sun Nov 15 2009 meissner@suse.de
- exif-0.6.19 (2009-11-12):
  * New translations: fi, ja
  * Updated translations: sv, vi, zh_CN
  * Fixed alignment of --list-tags header with --width
- exif-0.6.18 (2009-10-08):
  * New translations: is, it, lv
  * Updated translations: da, de, id, nl, pl, sk, sv, vi, zh_CN
  * Fixed alignment of tables in locales with multibyte character encoding
    (sfbug #2034873)
  * Allow setting --tag=0 (needed for the GPS IFD)
  * --ifd is now honoured while displaying tag contents
  * --create-exif now creates mandatory EXIF tags with default data
  * --no-fixup disables attempts to fix tags in existing files
  * --width option sets width of output lines
* Sat Nov  8 2008 meissner@suse.de
- upgraded to 0.6.17
  * Fixed the output of -s and -t when iconv is configured
  * Updated translations: pl
  * Added translations: id nl sk sv vi zh_CN
  * Fixed a double character encoding conversion problem with recent
    GNU gettext because version >= 0.10.36 does the conversion of message
    texts itself.
* Mon Oct 20 2008 meissner@suse.de
- upgraded to 0.6.16.1:
  * Fixed the output of -s and -t when iconv is configured
  * Updated translations: pl
  * Added translations: id nl sk sv vi zh_CN
  * Fixed a double character encoding conversion problem with recent
    GNU gettext because version >= 0.10.36 does the conversion of message
    texts itself.
- upgraded to 0.6.16:
  * Updated translations: pl
* Wed May 23 2007 meissner@suse.de
- upgraded to 0.6.15:
  - misc build fixes and cleanups
* Sat Mar  3 2007 aj@suse.de
- Fix BuildRequires.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Mar 31 2005 meissner@suse.de
- Upgraded to 0.6.13 version.
* Thu Jan 13 2005 meissner@suse.de
- Bugfixes, mnote printing enhanced.
* Thu Jul 29 2004 meissner@suse.de
- Upgraded to 0.6.10: stability fixes mostly and 0.6.* libexif
  support.
* Thu Feb 26 2004 hmacht@suse.de
- building as non-root
* Mon Feb 23 2004 meissner@suse.de
- No longer use libmnote, it is now integrated into libexif.
* Fri Sep  5 2003 meissner@suse.de
- use libmnote.
* Tue Aug 12 2003 postadal@suse.cz
- initial version 0.6
  * small command-line utility to show and change EXIF information hidden in JPEG files
